function pv = blkcrdlstproc(BCL, img, fn)
  
% blkcrdlstproc  -- Apply a function to each block specified in a
%                   block coordinate list structure
%
% Usage:
%       pv = blkcrdlstproc(BCL, img, fn)
%
% Input:
%       BCL          Block coordinate list structure
%       img          Image from which blocks are extracted
%       fn           Block function
%
% Output:
%       pv           Result matrix

r0 = BCL.BlkCrd(1,1); r1 = r0 + BCL.Nbr - 1;
c0 = BCL.BlkCrd(1,2); c1 = c0 + BCL.Nbc - 1;
bm = gray2nband(BCL.BlkMsk, size(img,3));
v = img(r0:r1, c0:c1, :);
pv = zeros(size(BCL.BlkCrd,1), prod(size(fn(v, bm))));

for k = 1:size(BCL.BlkCrd,1),
  
  r0 = BCL.BlkCrd(k,1); r1 = r0 + BCL.Nbr - 1;
  c0 = BCL.BlkCrd(k,2); c1 = c0 + BCL.Nbc - 1;
  v = img(r0:r1, c0:c1, :);
  pv(k,:) = fn(v, bm);

end

return
