function BCL = mskblkcrdlst(imsk, bmsk, Bd, Bs)

% mskblkcrdlst -- Construct a set of coordinates of image blocks
%                 intersecting a masked image region
%
% Usage:
%       crd = mskblkcrdlst(img, msk, Bs, Bi)
%
% Input:
%       imsk         The image region mask
%       bmsk         The block active region mask 
%       Bd           Block dimension vector (or scalar for NxN)
%       Bs           Block skip vector (or scalar for same skip in
%                    both dimensions)
%
% Output:
%       BCL          A struct containing block size, block mask,
%                    and a matrix of coordinates of block top-left
%                    corners

if nargin < 4,
  Bs = [1 1];
end
if prod(size(Bs)) == 1,
  Nsr = Bs;
  Nsc = Bs;
else
  Nsr = Bs(1);
  Nsc = Bs(2);
end
if prod(size(Bd)) == 1,
  Nbr = Bd;
  Nbc = Bd;
else
  Nbr = Bd(1);
  Nbc = Bd(2);
end
if isempty(bmsk),
  bmsk = ones(Nbr, Nbc);
end

[Nir Nic] = size(imsk);

Nib = length(1:Nsr:(Nir-Nbr+1))*length(1:Nsc:(Nic-Nbc+1));  
crd = zeros(Nib,2);

n = 1;
for l=1:Nsr:(Nir-Nbr+1),
  for m=1:Nsc:(Nic-Nbc+1),
    v = (bmsk == 1) .* (imsk(l:(l+Nbr-1),m:(m+Nbc-1)) == 0);
    if sum(v(:)) > 0,
      crd(n,:) = [l m];
      n = n + 1;
    end
  end
end

crd = crd(1:(n-1),:);

BCL = struct('Nbr', Nbr, 'Nbc', Nbc, 'BlkMsk', bmsk, 'BlkCrd', crd);

return
