rsltdsp = 1;
rsltwrt = 0;

% Set parameters
opt.Verbose = 1;
opt.BlockSize = [7 7];
opt.GridStep = [1 3 5];
opt.FuncGamma = [1.0 1.0];
opt.NormaliseBlocks = 0;
opt.BlkSrcRotations = [0];
opt.NNMaxDictSize = 2*prod(opt.BlockSize);
opt.NNMaxDist = 0.3;
opt.NNMinKnownFrac = 0.5;
opt.IKPBSearchRadius = 30;
opt.IKPBMaxDictSize = 5*prod(opt.BlockSize);
opt.InitCGTol = 1e-3;
opt.BPDNLambda = 5e-3;
opt.BPDNOpt.MaxMainIter = 10;
opt.BPDNOpt.CGTol = 1e-3;
opt.BPDNOpt.CGTolScale = 5;
opt.BPDNOpt.WeightThresh = 1e-4;
opt.BPDNOpt.CGTWTFactor = 1;
opt.DictPruneTol = 1e-5;

% Load test images
imgref = double(imread('fig3/reference.png'));
imgref = imgref(:,:,1);
rgnmsk = double(imread('fig3/mask.png'));
rgnmsk = rgnmsk(:,:,1)/255;
imgtst = imgref;
imgtst(rgnmsk ~= 1) = 0;
[xi,xj] = find(~rgnmsk);
rgncrd = [min(xi) min(xj) max(xi) max(xj)];

% Do sim. opt. inpainting
[imgjnt, iptinf] = jntoptinpaint(imgtst, rgnmsk, opt);
snript = snr(imgref(~rgnmsk), imgjnt(~rgnmsk));
ssmpipt = ssimmap(imgref, imgjnt);
ssimipt = mean(ssmpipt(~rgnmsk));

% Compute Criminisi result for comparison
[imgcrm, i2, i3, c, d] = cptinpaint(imgtst, rgnmsk == 0);
snrcrm = snr(imgref(~rgnmsk), imgcrm(~rgnmsk));
ssmpcrm = ssimmap(imgref, imgcrm);
ssimcrm = mean(ssmpcrm(~rgnmsk));

% Compare with Wexler result
imgwex = double(imread('fig3/wexler_result.png'));
snrwex = snr(imgref(~rgnmsk), imgwex(~rgnmsk));
ssmpwex = ssimmap(imgref, imgwex);
ssimwex = mean(ssmpwex(~rgnmsk));

% Compare with Xu & Sun result
imgxsn = double(imread('fig3/xu_sun_result.png'));
snrxsn = snr(imgref(~rgnmsk), imgxsn(~rgnmsk));
ssmpxsn = ssimmap(imgref, imgxsn);
ssimxsn = mean(ssmpxsn(~rgnmsk));

 % Display performance measurements
disp('       Joint Opt. Criminisi     Wexler   Xu & Sun');
disp(sprintf('SNR      %5.2fdb    %5.2fdb    %5.2fdb    %5.2fdb', ...
             snript, snrcrm, snrwex, snrxsn));
disp(sprintf('SSIM     %5.2f      %5.2f      %5.2f      %5.2f', ...
             ssimipt, ssimcrm, ssimwex, ssimxsn));


if rsltdsp,
  dopt = struct('bregion', rgncrd, 'zgap', 8);
  figure;
  subplot(2,3,1),
  imdisp(imgref, dopt); title('Reference image');
  subplot(2,3,2),
  imdisp(imgjnt, dopt); title('Joint opt. inpainted image');
  subplot(2,3,3),
  imdisp(imgcrm, dopt); title('Criminisi inpainted image');
  subplot(2,3,4),
  imdisp(imgwex, dopt); title('Wexler inpainted image');
  subplot(2,3,5),
  imdisp(imgwex, dopt); title('Xu & Sun inpainted image');
end



if rsltwrt,
  zgap = 4;
  zcrd = rgncrd + zgap* [-1 -1 1 1];

  refimg = imbox(imgref, rgncrd);
  refimg = refimg(zcrd(1):zcrd(3),zcrd(2):zcrd(4),:);
  imwrite(uint8(refimg), 'fig3/region_ref.png');

  jntimg = imgjnt(zcrd(1):zcrd(3),zcrd(2):zcrd(4),:);
  imwrite(uint8(jntimg), 'fig3/region_jnt.png');
  
  crmimg = imgcrm(zcrd(1):zcrd(3),zcrd(2):zcrd(4),:);
  imwrite(uint8(crmimg), 'fig3/region_crm.png');
  
  weximg = imgwex(zcrd(1):zcrd(3),zcrd(2):zcrd(4),:);
  imwrite(uint8(weximg), 'fig3/region_wex.png');
  
  xsnimg = imgxsn(zcrd(1):zcrd(3),zcrd(2):zcrd(4),:);
  imwrite(uint8(xsnimg), 'fig3/region_xsn.png');
end



% >> fig3
% Constructing dictionaries
%   Using 3 grids of 7x7 blocks
%     Grid 1 (offset 1,1) has 20 blocks (8 have NND)
%     Grid 2 (offset 3,3) has 25 blocks (9 have NND)
%     Grid 3 (offset 5,5) has 20 blocks (5 have NND)
%   Vector lengths
%     Concatentated dict. coeff.:  14075
%     Known region penalty      :    917
%     Block overlap penalty     :   1512
% Constructing initial CG solution  (problem size 2429x14075)
% Performing sparse optimisation (problem size 2429x14075)
% Itn  Fnc       DFid      Reg       WFnc      WDFid     WReg      RelRes    CGIt  Flg
% ------------------------------------------------------------------------------------
%   1  1.95e+00  1.24e+00  1.42e+02  1.95e+00  1.24e+00  1.42e+02  1.62e-04   386   0
%   2  1.28e+00  5.58e-01  1.44e+02  1.28e+00  5.58e-01  1.44e+02  3.13e-05   834   0
%   3  1.10e+00  3.82e-01  1.44e+02  1.10e+00  3.82e-01  1.44e+02  7.77e-06  1298   0
%   4  1.03e+00  3.09e-01  1.44e+02  1.03e+00  3.09e-01  1.44e+02  4.81e-06  1451   0
%   5  9.90e-01  2.73e-01  1.43e+02  9.90e-01  2.73e-01  1.43e+02  3.74e-06  1439   0
%   6  9.67e-01  2.52e-01  1.43e+02  9.67e-01  2.52e-01  1.43e+02  3.63e-06  1332   0
%   7  9.53e-01  2.39e-01  1.43e+02  9.52e-01  2.39e-01  1.43e+02  3.13e-06  1354   0
%   8  9.43e-01  2.31e-01  1.42e+02  9.43e-01  2.31e-01  1.42e+02  2.87e-06  1394   0
%   9  9.36e-01  2.25e-01  1.42e+02  9.36e-01  2.25e-01  1.42e+02  2.48e-06  1410   0
%  10  9.31e-01  2.21e-01  1.42e+02  9.31e-01  2.21e-01  1.42e+02  2.29e-06  1340   0
% ------------------------------------------------------------------------------------
%        Sim. Opt.  Criminisi     Wexler   Xu & Sun
% SNR      12.89db     4.50db     5.75db     8.73db
% SSIM      0.93       0.66       0.76       0.86
