function mp = ssimmap(img1, img2)

% ssimmap -- Compute SSIM index map for a pair of images and
%            zero-pad to the size of the input images so that the
%            index map and input images are aligned. RGB inputs are
%            converted to greyscale before computing the SSIM index
%            map.
%
% Usage:
%       mp = ssimmap(img1, img2)
%
% Input:
%       img1        First input image
%       img2        Second input image
%
% Output:
%       mp          SSIM map

if size(img1,3) == 3,
  img1 = rgbtogrey(img1);
end
if size(img2,3) == 3,
  img2 = rgbtogrey(img2);
end
if isfloat(img1) && isfloat(img2),
  a = max(max(img1(:)),max(img2(:)));
  img1 = (255/a)*img1;
  img2 = (255/a)*img2;
end

[mssim, ssim_map] = ssim_index(img1, img2);
W = size(img1) - size(ssim_map) + 1;
R = ceil(W/2) - 1;
Rr = R(1); Rc = R(2);
mp = zeros(size(img1));
mp((1+Rr):(Rr+size(ssim_map,1)),(1+Rc):(Rc+size(ssim_map,2))) = ssim_map;

return
