function [Un, S] = optscaledict(U, v)

% optscaledict -- Scale each column of a dictionary matrix to minimise
%                 the l2 distance from a specified vector
%
% Usage:
%       [Un, S] = optscaledict(U, v)
%
% Input:
%       U           Input dictionary matrix
%       v           Target vector
%
% Output:
%       Un          Scaled dictionary matrix
%       S           Vector of applied scaling factors

S = sum(repmat(v(:),1,size(U,2)).*U,1) ./ sum(U.^2,1);
Un = repmat(S,size(U,1),1).*U;

return
