function im = dictvisim(D, sz)
  
% dictvisim -- Construct an image allowing visualization of dictionary
%              content
%
% Usage:
%       im = dictvisim(D, sz)
%
% Input:
%       D           Dictionary matrix
%       sz          Size of each block in dictionary
%       
% Output:
%       im          Image tiled with dictionary entries

if length(sz) == 2,
  sz = [sz 1];
end

N = size(D,2);
Vr = floor(sqrt(N));
Vc = ceil(N/Vr);
im = zeros(Vr*sz(1) + Vr-1, Vc*sz(2) + Vc-1, sz(3));
k = 1;
for l = 0:(Vr-1),
  for m = 0:(Vc-1),   
    r = sz(1)*l + l + 1;
    c = sz(2)*m + m + 1;
    im(r:(r+sz(1)-1),c:(c+sz(2)-1),:) = reshape(D(:,k),sz);
    k = k + 1;
    if k > N,
      break;
    end
  end
  if k > N,
    break;
  end
end

return
