function u = imbox(v, crd, clr)

% imbox -- Return an image with the specified box drawn on it
%
% Usage:
%       u = imbox(v, crd, clr)
%
% Input:
%       v           Input image
%       crd         Box coordinates in the form [ymin xmin ymax xmax]
%       clr         Box color in the form [r g b]
%  
% Output:
%       u           Output image

if nargin < 3,
  clr = [255 0 0];
end

if size(v,3) == 1,
  u = uint8(cat(3, v, v, v));
else
  u = uint8(v);  
end
for c = 1:3,
  u(crd(1):crd(3), crd(2), c) = clr(c);
  u(crd(1):crd(3), crd(4), c) = clr(c);
  u(crd(1), crd(2):crd(4), c) = clr(c);
  u(crd(3), crd(2):crd(4), c) = clr(c);
end

return
