function v = rnkval(u, r)

% rnkval -- Determine the value in a vector corresponding to the
%           specified (fractional) rank, where 0 corresponds to
%           the smallest element, and 1 corresponds to the largest
%           element.
%
% Usage:
%       v = rnkval(u, r)
%
% Input:
%       u           Vector of values
%       r           Fractional rank (scalar or vector)
%  
% Output:
%       v           Rank value

% Handle non-conforming parameters
r(r < 0) = 0;
r(r > 1) = 1;
if size(u,1)>size(u,2),
  u = u';
end

% Compute rank values
ri = r*(size(u,2)-1) + 1;
rf = floor(ri);
rc = ceil(ri);
us = sort(u);
v = (rf == rc).*us(rf) + (rf ~= rc).*((rc-ri).*us(rf) + (ri-rf).*us(rc));

return

